Class: Aws::KinesisVideo::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KinesisVideo::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kinesisvideo/client.rb,
sig/client.rbs
Overview
An API client for KinesisVideo. To construct a client, you need to configure a :region and :credentials.
client = Aws::KinesisVideo::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CreateSignalingChannelResponseSuccess, _CreateStreamResponseSuccess, _DeleteEdgeConfigurationResponseSuccess, _DeleteSignalingChannelResponseSuccess, _DeleteStreamResponseSuccess, _DescribeEdgeConfigurationResponseSuccess, _DescribeImageGenerationConfigurationResponseSuccess, _DescribeMappedResourceConfigurationResponseSuccess, _DescribeMediaStorageConfigurationResponseSuccess, _DescribeNotificationConfigurationResponseSuccess, _DescribeSignalingChannelResponseSuccess, _DescribeStreamResponseSuccess, _DescribeStreamStorageConfigurationResponseSuccess, _GetDataEndpointResponseSuccess, _GetSignalingChannelEndpointResponseSuccess, _ListEdgeAgentConfigurationsResponseSuccess, _ListSignalingChannelsResponseSuccess, _ListStreamsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListTagsForStreamResponseSuccess, _StartEdgeConfigurationUpdateResponseSuccess, _TagResourceResponseSuccess, _TagStreamResponseSuccess, _UntagResourceResponseSuccess, _UntagStreamResponseSuccess, _UpdateDataRetentionResponseSuccess, _UpdateImageGenerationConfigurationResponseSuccess, _UpdateMediaStorageConfigurationResponseSuccess, _UpdateNotificationConfigurationResponseSuccess, _UpdateSignalingChannelResponseSuccess, _UpdateStreamResponseSuccess, _UpdateStreamStorageConfigurationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_signaling_channel(params = {}) ⇒ Types::CreateSignalingChannelOutput
Creates a signaling channel.
-
#create_stream(params = {}) ⇒ Types::CreateStreamOutput
Creates a new Kinesis video stream.
-
#delete_edge_configuration(params = {}) ⇒ Struct
An asynchronous API that deletes a stream’s existing edge configuration, as well as the corresponding media from the Edge Agent.
-
#delete_signaling_channel(params = {}) ⇒ Struct
Deletes a specified signaling channel.
-
#delete_stream(params = {}) ⇒ Struct
Deletes a Kinesis video stream and the data contained in the stream.
-
#describe_edge_configuration(params = {}) ⇒ Types::DescribeEdgeConfigurationOutput
Describes a stream’s edge configuration that was set using the
StartEdgeConfigurationUpdateAPI and the latest status of the edge agent's recorder and uploader jobs. -
#describe_image_generation_configuration(params = {}) ⇒ Types::DescribeImageGenerationConfigurationOutput
Gets the
ImageGenerationConfigurationfor a given Kinesis video stream. -
#describe_mapped_resource_configuration(params = {}) ⇒ Types::DescribeMappedResourceConfigurationOutput
Returns the most current information about the stream.
-
#describe_media_storage_configuration(params = {}) ⇒ Types::DescribeMediaStorageConfigurationOutput
Returns the most current information about the channel.
-
#describe_notification_configuration(params = {}) ⇒ Types::DescribeNotificationConfigurationOutput
Gets the
NotificationConfigurationfor a given Kinesis video stream. -
#describe_signaling_channel(params = {}) ⇒ Types::DescribeSignalingChannelOutput
Returns the most current information about the signaling channel.
-
#describe_stream(params = {}) ⇒ Types::DescribeStreamOutput
Returns the most current information about the specified stream.
-
#describe_stream_storage_configuration(params = {}) ⇒ Types::DescribeStreamStorageConfigurationOutput
Retrieves the current storage configuration for the specified Kinesis video stream.
-
#get_data_endpoint(params = {}) ⇒ Types::GetDataEndpointOutput
Gets an endpoint for a specified stream for either reading or writing.
-
#get_signaling_channel_endpoint(params = {}) ⇒ Types::GetSignalingChannelEndpointOutput
Provides an endpoint for the specified signaling channel to send and receive messages.
-
#list_edge_agent_configurations(params = {}) ⇒ Types::ListEdgeAgentConfigurationsOutput
Returns an array of edge configurations associated with the specified Edge Agent.
-
#list_signaling_channels(params = {}) ⇒ Types::ListSignalingChannelsOutput
Returns an array of
ChannelInfoobjects. -
#list_streams(params = {}) ⇒ Types::ListStreamsOutput
Returns an array of
StreamInfoobjects. -
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags associated with the specified signaling channel.
-
#list_tags_for_stream(params = {}) ⇒ Types::ListTagsForStreamOutput
Returns a list of tags associated with the specified stream.
-
#start_edge_configuration_update(params = {}) ⇒ Types::StartEdgeConfigurationUpdateOutput
An asynchronous API that updates a stream’s existing edge configuration.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a signaling channel.
-
#tag_stream(params = {}) ⇒ Struct
Adds one or more tags to a stream.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a signaling channel.
-
#untag_stream(params = {}) ⇒ Struct
Removes one or more tags from a stream.
-
#update_data_retention(params = {}) ⇒ Struct
Increases or decreases the stream's data retention period by the value that you specify.
-
#update_image_generation_configuration(params = {}) ⇒ Struct
Updates the
StreamInfoandImageProcessingConfigurationfields. -
#update_media_storage_configuration(params = {}) ⇒ Struct
Associates a
SignalingChannelto a stream to store the media. -
#update_notification_configuration(params = {}) ⇒ Struct
Updates the notification information for a stream.
-
#update_signaling_channel(params = {}) ⇒ Struct
Updates the existing signaling channel.
-
#update_stream(params = {}) ⇒ Struct
Updates stream metadata, such as the device name and media type.
-
#update_stream_storage_configuration(params = {}) ⇒ Struct
Updates the storage configuration for an existing Kinesis video stream.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2162 2163 2164 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2162 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2165 2166 2167 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2165 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2135 2136 2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2135 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::KinesisVideo') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kinesisvideo' context[:gem_version] = '1.97.0' Seahorse::Client::Request.new(handlers, context) end |
#create_signaling_channel(params = {}) ⇒ Types::CreateSignalingChannelOutput
Creates a signaling channel.
CreateSignalingChannel is an asynchronous operation.
86 |
# File 'sig/client.rbs', line 86
def create_signaling_channel: (
|
#create_stream(params = {}) ⇒ Types::CreateStreamOutput
Creates a new Kinesis video stream.
When you create a new stream, Kinesis Video Streams assigns it a version number. When you change the stream's metadata, Kinesis Video Streams updates the version.
CreateStream is an asynchronous operation.
For information about how the service works, see How it Works.
You must have permissions for the KinesisVideo:CreateStream action.
106 |
# File 'sig/client.rbs', line 106
def create_stream: (
|
#delete_edge_configuration(params = {}) ⇒ Struct
An asynchronous API that deletes a stream’s existing edge configuration, as well as the corresponding media from the Edge Agent.
When you invoke this API, the sync status is set to DELETING. A
deletion process starts, in which active edge jobs are stopped and all
media is deleted from the edge device. The time to delete varies,
depending on the total amount of stored media. If the deletion process
fails, the sync status changes to DELETE_FAILED. You will need to
re-try the deletion.
When the deletion process has completed successfully, the edge configuration is no longer accessible.
123 |
# File 'sig/client.rbs', line 123
def delete_edge_configuration: (
|
#delete_signaling_channel(params = {}) ⇒ Struct
Deletes a specified signaling channel. DeleteSignalingChannel is an
asynchronous operation. If you don't specify the channel's current
version, the most recent version is deleted.
133 |
# File 'sig/client.rbs', line 133
def delete_signaling_channel: (
|
#delete_stream(params = {}) ⇒ Struct
Deletes a Kinesis video stream and the data contained in the stream.
This method marks the stream for deletion, and makes the data in the stream inaccessible immediately.
To ensure that you have the latest version of the stream before
deleting it, you can specify the stream version. Kinesis Video Streams
assigns a version to each stream. When you update a stream, Kinesis
Video Streams assigns a new version number. To get the latest stream
version, use the DescribeStream API.
This operation requires permission for the KinesisVideo:DeleteStream
action.
143 |
# File 'sig/client.rbs', line 143
def delete_stream: (
|
#describe_edge_configuration(params = {}) ⇒ Types::DescribeEdgeConfigurationOutput
Describes a stream’s edge configuration that was set using the
StartEdgeConfigurationUpdate API and the latest status of the edge
agent's recorder and uploader jobs. Use this API to get the status of
the configuration to determine if the configuration is in sync with
the Edge Agent. Use this API to evaluate the health of the Edge Agent.
161 |
# File 'sig/client.rbs', line 161
def describe_edge_configuration: (
|
#describe_image_generation_configuration(params = {}) ⇒ Types::DescribeImageGenerationConfigurationOutput
Gets the ImageGenerationConfiguration for a given Kinesis video
stream.
172 |
# File 'sig/client.rbs', line 172
def describe_image_generation_configuration: (
|
#describe_mapped_resource_configuration(params = {}) ⇒ Types::DescribeMappedResourceConfigurationOutput
Returns the most current information about the stream. The
streamName or streamARN should be provided in the input.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
184 |
# File 'sig/client.rbs', line 184
def describe_mapped_resource_configuration: (
|
#describe_media_storage_configuration(params = {}) ⇒ Types::DescribeMediaStorageConfigurationOutput
Returns the most current information about the channel. Specify the
ChannelName or ChannelARN in the input.
197 |
# File 'sig/client.rbs', line 197
def describe_media_storage_configuration: (
|
#describe_notification_configuration(params = {}) ⇒ Types::DescribeNotificationConfigurationOutput
Gets the NotificationConfiguration for a given Kinesis video stream.
208 |
# File 'sig/client.rbs', line 208
def describe_notification_configuration: (
|
#describe_signaling_channel(params = {}) ⇒ Types::DescribeSignalingChannelOutput
Returns the most current information about the signaling channel. You must specify either the name or the Amazon Resource Name (ARN) of the channel that you want to describe.
219 |
# File 'sig/client.rbs', line 219
def describe_signaling_channel: (
|
#describe_stream(params = {}) ⇒ Types::DescribeStreamOutput
Returns the most current information about the specified stream. You
must specify either the StreamName or the StreamARN.
230 |
# File 'sig/client.rbs', line 230
def describe_stream: (
|
#describe_stream_storage_configuration(params = {}) ⇒ Types::DescribeStreamStorageConfigurationOutput
Retrieves the current storage configuration for the specified Kinesis video stream.
In the request, you must specify either the StreamName or the
StreamARN.
You must have permissions for the
KinesisVideo:DescribeStreamStorageConfiguration action.
243 |
# File 'sig/client.rbs', line 243
def describe_stream_storage_configuration: (
|
#get_data_endpoint(params = {}) ⇒ Types::GetDataEndpointOutput
Gets an endpoint for a specified stream for either reading or writing.
Use this endpoint in your application to read from the specified
stream (using the GetMedia or GetMediaForFragmentList operations)
or write to it (using the PutMedia operation).
In the request, specify the stream either by StreamName or
StreamARN.
254 |
# File 'sig/client.rbs', line 254
def get_data_endpoint: (
|
#get_signaling_channel_endpoint(params = {}) ⇒ Types::GetSignalingChannelEndpointOutput
Provides an endpoint for the specified signaling channel to send and
receive messages. This API uses the
SingleMasterChannelEndpointConfiguration input parameter, which
consists of the Protocols and Role properties.
Protocols is used to determine the communication mechanism. For
example, if you specify WSS as the protocol, this API produces a
secure websocket endpoint. If you specify HTTPS as the protocol,
this API generates an HTTPS endpoint. If you specify WEBRTC as the
protocol, but the signaling channel isn't configured for ingestion,
you will receive the error InvalidArgumentException.
Role determines the messaging permissions. A MASTER role results
in this API generating an endpoint that a client can use to
communicate with any of the viewers on the channel. A VIEWER role
results in this API generating an endpoint that a client can use to
communicate only with a MASTER.
266 |
# File 'sig/client.rbs', line 266
def get_signaling_channel_endpoint: (
|
#list_edge_agent_configurations(params = {}) ⇒ Types::ListEdgeAgentConfigurationsOutput
Returns an array of edge configurations associated with the specified Edge Agent.
In the request, you must specify the Edge Agent HubDeviceArn.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
281 |
# File 'sig/client.rbs', line 281
def list_edge_agent_configurations: (
|
#list_signaling_channels(params = {}) ⇒ Types::ListSignalingChannelsOutput
Returns an array of ChannelInfo objects. Each object describes a
signaling channel. To retrieve only those channels that satisfy a
specific condition, you can specify a ChannelNameCondition.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
294 |
# File 'sig/client.rbs', line 294
def list_signaling_channels: (
|
#list_streams(params = {}) ⇒ Types::ListStreamsOutput
Returns an array of StreamInfo objects. Each object describes a
stream. To retrieve only streams that satisfy a specific condition,
you can specify a StreamNameCondition.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
310 |
# File 'sig/client.rbs', line 310
def list_streams: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags associated with the specified signaling channel.
326 |
# File 'sig/client.rbs', line 326
def list_tags_for_resource: (
|
#list_tags_for_stream(params = {}) ⇒ Types::ListTagsForStreamOutput
Returns a list of tags associated with the specified stream.
In the request, you must specify either the StreamName or the
StreamARN.
338 |
# File 'sig/client.rbs', line 338
def list_tags_for_stream: (
|
#start_edge_configuration_update(params = {}) ⇒ Types::StartEdgeConfigurationUpdateOutput
An asynchronous API that updates a stream’s existing edge
configuration. The Kinesis Video Stream will sync the stream’s edge
configuration with the Edge Agent IoT Greengrass component that runs
on an IoT Hub Device, setup at your premise. The time to sync can vary
and depends on the connectivity of the Hub Device. The SyncStatus
will be updated as the edge configuration is acknowledged, and synced
with the Edge Agent.
If this API is invoked for the first time, a new edge configuration
will be created for the stream, and the sync status will be set to
SYNCING. You will have to wait for the sync status to reach a
terminal state such as: IN_SYNC, or SYNC_FAILED, before using this
API again. If you invoke this API during the syncing process, a
ResourceInUseException will be thrown. The connectivity of the
stream’s edge configuration and the Edge Agent will be retried for 15
minutes. After 15 minutes, the status will transition into the
SYNC_FAILED state.
To move an edge configuration from one device to another, use DeleteEdgeConfiguration to delete the current edge configuration. You can then invoke StartEdgeConfigurationUpdate with an updated Hub Device ARN.
356 |
# File 'sig/client.rbs', line 356
def start_edge_configuration_update: (
|
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a signaling channel. A tag is a key-value pair (the value is optional) that you can define and assign to Amazon Web Services resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. For more information, see Using Cost Allocation Tags in the Billing and Cost Management and Cost Management User Guide.
393 |
# File 'sig/client.rbs', line 393
def tag_resource: (
|
#tag_stream(params = {}) ⇒ Struct
Adds one or more tags to a stream. A tag is a key-value pair (the value is optional) that you can define and assign to Amazon Web Services resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. For more information, see Using Cost Allocation Tags in the Billing and Cost Management and Cost Management User Guide.
You must provide either the StreamName or the StreamARN.
This operation requires permission for the KinesisVideo:TagStream
action.
A Kinesis video stream can support up to 50 tags.
408 |
# File 'sig/client.rbs', line 408
def tag_stream: (
|
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a signaling channel. In the request, specify only a tag key or keys; don't specify the value. If you specify a tag key that does not exist, it's ignored.
419 |
# File 'sig/client.rbs', line 419
def untag_resource: (
|
#untag_stream(params = {}) ⇒ Struct
Removes one or more tags from a stream. In the request, specify only a tag key or keys; don't specify the value. If you specify a tag key that does not exist, it's ignored.
In the request, you must provide the StreamName or StreamARN.
429 |
# File 'sig/client.rbs', line 429
def untag_stream: (
|
#update_data_retention(params = {}) ⇒ Struct
Increases or decreases the stream's data retention period by the
value that you specify. To indicate whether you want to increase or
decrease the data retention period, specify the Operation parameter
in the request body. In the request, you must specify either the
StreamName or the StreamARN.
This operation requires permission for the
KinesisVideo:UpdateDataRetention action.
Changing the data retention period affects the data in the stream as follows:
-
If the data retention period is increased, existing data is retained for the new retention period. For example, if the data retention period is increased from one hour to seven hours, all existing data is retained for seven hours.
-
If the data retention period is decreased, existing data is retained for the new retention period. For example, if the data retention period is decreased from seven hours to one hour, all existing data is retained for one hour, and any data older than one hour is deleted immediately.
440 |
# File 'sig/client.rbs', line 440
def update_data_retention: (
|
#update_image_generation_configuration(params = {}) ⇒ Struct
Updates the StreamInfo and ImageProcessingConfiguration fields.
453 |
# File 'sig/client.rbs', line 453
def update_image_generation_configuration: (
|
#update_media_storage_configuration(params = {}) ⇒ Struct
Associates a SignalingChannel to a stream to store the media. There
are two signaling modes that you can specify :
-
If
StorageStatusis enabled, the data will be stored in theStreamARNprovided. In order for WebRTC Ingestion to work, the stream must have data retention enabled. -
If
StorageStatusis disabled, no data will be stored, and theStreamARNparameter will not be needed.
If StorageStatus is enabled, direct peer-to-peer (master-viewer)
connections no longer occur. Peers connect directly to the storage
session. You must call the JoinStorageSession API to trigger an SDP
offer send and establish a connection between a peer and the storage
session.
476 |
# File 'sig/client.rbs', line 476
def update_media_storage_configuration: (
|
#update_notification_configuration(params = {}) ⇒ Struct
Updates the notification information for a stream.
489 |
# File 'sig/client.rbs', line 489
def update_notification_configuration: (
|
#update_signaling_channel(params = {}) ⇒ Struct
Updates the existing signaling channel. This is an asynchronous operation and takes time to complete.
If the MessageTtlSeconds value is updated (either increased or
reduced), it only applies to new messages sent via this channel after
it's been updated. Existing messages are still expired as per the
previous MessageTtlSeconds value.
505 |
# File 'sig/client.rbs', line 505
def update_signaling_channel: (
|
#update_stream(params = {}) ⇒ Struct
Updates stream metadata, such as the device name and media type.
You must provide the stream name or the Amazon Resource Name (ARN) of the stream.
To make sure that you have the latest version of the stream before
updating it, you can specify the stream version. Kinesis Video Streams
assigns a version to each stream. When you update a stream, Kinesis
Video Streams assigns a new version number. To get the latest stream
version, use the DescribeStream API.
UpdateStream is an asynchronous operation, and takes time to
complete.
518 |
# File 'sig/client.rbs', line 518
def update_stream: (
|
#update_stream_storage_configuration(params = {}) ⇒ Struct
Updates the storage configuration for an existing Kinesis video stream.
This operation allows you to modify the storage tier settings for a stream, enabling you to optimize storage costs and performance based on your access patterns.
UpdateStreamStorageConfiguration is an asynchronous operation.
You must have permissions for the
KinesisVideo:UpdateStreamStorageConfiguration action.
531 |
# File 'sig/client.rbs', line 531
def update_stream_storage_configuration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2155 2156 2157 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2155 def waiter_names [] end |