Class: Aws::KinesisVideo::Types::DescribeStreamStorageConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisvideo/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#stream_arnString

The Amazon Resource Name (ARN) of the stream for which you want to retrieve the storage configuration.

Returns:

  • (String)


691
692
693
694
695
696
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 691

class DescribeStreamStorageConfigurationInput < Struct.new(
  :stream_name,
  :stream_arn)
  SENSITIVE = []
  include Aws::Structure
end

#stream_nameString

The name of the stream for which you want to retrieve the storage configuration.

Returns:

  • (String)


691
692
693
694
695
696
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 691

class DescribeStreamStorageConfigurationInput < Struct.new(
  :stream_name,
  :stream_arn)
  SENSITIVE = []
  include Aws::Structure
end