Class: Aws::KinesisVideo::Types::DescribeStreamStorageConfigurationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisVideo::Types::DescribeStreamStorageConfigurationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisvideo/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the stream.
-
#stream_name ⇒ String
The name of the stream.
-
#stream_storage_configuration ⇒ Types::StreamStorageConfiguration
The current storage configuration for the stream, including the default storage tier and other storage-related settings.
Instance Attribute Details
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the stream.
713 714 715 716 717 718 719 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 713 class DescribeStreamStorageConfigurationOutput < Struct.new( :stream_name, :stream_arn, :stream_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the stream.
713 714 715 716 717 718 719 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 713 class DescribeStreamStorageConfigurationOutput < Struct.new( :stream_name, :stream_arn, :stream_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#stream_storage_configuration ⇒ Types::StreamStorageConfiguration
The current storage configuration for the stream, including the default storage tier and other storage-related settings.
713 714 715 716 717 718 719 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 713 class DescribeStreamStorageConfigurationOutput < Struct.new( :stream_name, :stream_arn, :stream_storage_configuration) SENSITIVE = [] include Aws::Structure end |