Class: Aws::KinesisVideo::Types::ListSignalingChannelsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisVideo::Types::ListSignalingChannelsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisvideo/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_name_condition ⇒ Types::ChannelNameCondition
Optional: Returns only the channels that satisfy a specific condition.
-
#max_results ⇒ Integer
The maximum number of channels to return in the response.
-
#next_token ⇒ String
If you specify this parameter, when the result of a
ListSignalingChannelsoperation is truncated, the call returns theNextTokenin the response.
Instance Attribute Details
#channel_name_condition ⇒ Types::ChannelNameCondition
Optional: Returns only the channels that satisfy a specific condition.
1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 1171 class ListSignalingChannelsInput < Struct.new( :max_results, :next_token, :channel_name_condition) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of channels to return in the response. The default is 500.
1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 1171 class ListSignalingChannelsInput < Struct.new( :max_results, :next_token, :channel_name_condition) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If you specify this parameter, when the result of a
ListSignalingChannels operation is truncated, the call returns the
NextToken in the response. To get another batch of channels,
provide this token in your next request.
1171 1172 1173 1174 1175 1176 1177 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 1171 class ListSignalingChannelsInput < Struct.new( :max_results, :next_token, :channel_name_condition) SENSITIVE = [] include Aws::Structure end |