Class: Aws::KinesisVideo::Types::ListStreamsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisvideo/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of streams to return in the response. The default is 10,000.

Returns:



1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 1218

class ListStreamsInput < Struct.new(
  :max_results,
  :next_token,
  :stream_name_condition)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If you specify this parameter, when the result of a ListStreams operation is truncated, the call returns the NextToken in the response. To get another batch of streams, provide this token in your next request.

Returns:



1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 1218

class ListStreamsInput < Struct.new(
  :max_results,
  :next_token,
  :stream_name_condition)
  SENSITIVE = []
  include Aws::Structure
end

#stream_name_conditionTypes::StreamNameCondition

Optional: Returns only streams that satisfy a specific condition. Currently, you can specify only the prefix of a stream name as a condition.

Returns:



1218
1219
1220
1221
1222
1223
1224
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 1218

class ListStreamsInput < Struct.new(
  :max_results,
  :next_token,
  :stream_name_condition)
  SENSITIVE = []
  include Aws::Structure
end