Class: Aws::KinesisVideo::Types::MediaStorageConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisVideo::Types::MediaStorageConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisvideo/types.rb
Overview
A structure that encapsulates, or contains, the media storage configuration properties.
-
If
StorageStatusis enabled, the data will be stored in theStreamARNprovided. In order for WebRTC Ingestion to work, the stream must have data retention enabled. -
If
StorageStatusis disabled, no data will be stored, and theStreamARNparameter will not be needed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#status ⇒ String
The status of the media storage configuration.
-
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the stream.
Instance Attribute Details
#status ⇒ String
The status of the media storage configuration.
1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 1424 class MediaStorageConfiguration < Struct.new( :stream_arn, :status) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the stream.
1424 1425 1426 1427 1428 1429 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 1424 class MediaStorageConfiguration < Struct.new( :stream_arn, :status) SENSITIVE = [] include Aws::Structure end |