Class: Aws::KinesisVideo::Types::UpdateStreamStorageConfigurationInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-kinesisvideo/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_versionString

The version of the stream whose storage configuration you want to change. To get the version, call either the ‘DescribeStream` or the `ListStreams` API.

Returns:

  • (String)


2257
2258
2259
2260
2261
2262
2263
2264
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 2257

class UpdateStreamStorageConfigurationInput < Struct.new(
  :stream_name,
  :stream_arn,
  :current_version,
  :stream_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stream_arnString

The Amazon Resource Name (ARN) of the stream for which you want to update the storage configuration.

Returns:

  • (String)


2257
2258
2259
2260
2261
2262
2263
2264
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 2257

class UpdateStreamStorageConfigurationInput < Struct.new(
  :stream_name,
  :stream_arn,
  :current_version,
  :stream_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stream_nameString

The name of the stream for which you want to update the storage configuration.

Returns:

  • (String)


2257
2258
2259
2260
2261
2262
2263
2264
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 2257

class UpdateStreamStorageConfigurationInput < Struct.new(
  :stream_name,
  :stream_arn,
  :current_version,
  :stream_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#stream_storage_configurationTypes::StreamStorageConfiguration

The new storage configuration for the stream. This includes the default storage tier that determines how stream data is stored and accessed.

Different storage tiers offer varying levels of performance and cost optimization to match your specific use case requirements.



2257
2258
2259
2260
2261
2262
2263
2264
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 2257

class UpdateStreamStorageConfigurationInput < Struct.new(
  :stream_name,
  :stream_arn,
  :current_version,
  :stream_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end