Class: Aws::KinesisVideo::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::KinesisVideo::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-kinesisvideo/client.rb
Overview
An API client for KinesisVideo. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::KinesisVideo::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_signaling_channel(params = {}) ⇒ Types::CreateSignalingChannelOutput
Creates a signaling channel.
-
#create_stream(params = {}) ⇒ Types::CreateStreamOutput
Creates a new Kinesis video stream.
-
#delete_edge_configuration(params = {}) ⇒ Struct
An asynchronous API that deletes a stream’s existing edge configuration, as well as the corresponding media from the Edge Agent.
-
#delete_signaling_channel(params = {}) ⇒ Struct
Deletes a specified signaling channel.
-
#delete_stream(params = {}) ⇒ Struct
Deletes a Kinesis video stream and the data contained in the stream.
-
#describe_edge_configuration(params = {}) ⇒ Types::DescribeEdgeConfigurationOutput
Describes a stream’s edge configuration that was set using the ‘StartEdgeConfigurationUpdate` API and the latest status of the edge agent’s recorder and uploader jobs.
-
#describe_image_generation_configuration(params = {}) ⇒ Types::DescribeImageGenerationConfigurationOutput
Gets the ‘ImageGenerationConfiguration` for a given Kinesis video stream.
-
#describe_mapped_resource_configuration(params = {}) ⇒ Types::DescribeMappedResourceConfigurationOutput
Returns the most current information about the stream.
-
#describe_media_storage_configuration(params = {}) ⇒ Types::DescribeMediaStorageConfigurationOutput
Returns the most current information about the channel.
-
#describe_notification_configuration(params = {}) ⇒ Types::DescribeNotificationConfigurationOutput
Gets the ‘NotificationConfiguration` for a given Kinesis video stream.
-
#describe_signaling_channel(params = {}) ⇒ Types::DescribeSignalingChannelOutput
Returns the most current information about the signaling channel.
-
#describe_stream(params = {}) ⇒ Types::DescribeStreamOutput
Returns the most current information about the specified stream.
-
#describe_stream_storage_configuration(params = {}) ⇒ Types::DescribeStreamStorageConfigurationOutput
Retrieves the current storage configuration for the specified Kinesis video stream.
-
#get_data_endpoint(params = {}) ⇒ Types::GetDataEndpointOutput
Gets an endpoint for a specified stream for either reading or writing.
-
#get_signaling_channel_endpoint(params = {}) ⇒ Types::GetSignalingChannelEndpointOutput
Provides an endpoint for the specified signaling channel to send and receive messages.
-
#list_edge_agent_configurations(params = {}) ⇒ Types::ListEdgeAgentConfigurationsOutput
Returns an array of edge configurations associated with the specified Edge Agent.
-
#list_signaling_channels(params = {}) ⇒ Types::ListSignalingChannelsOutput
Returns an array of ‘ChannelInfo` objects.
-
#list_streams(params = {}) ⇒ Types::ListStreamsOutput
Returns an array of ‘StreamInfo` objects.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags associated with the specified signaling channel.
-
#list_tags_for_stream(params = {}) ⇒ Types::ListTagsForStreamOutput
Returns a list of tags associated with the specified stream.
-
#start_edge_configuration_update(params = {}) ⇒ Types::StartEdgeConfigurationUpdateOutput
An asynchronous API that updates a stream’s existing edge configuration.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a signaling channel.
-
#tag_stream(params = {}) ⇒ Struct
Adds one or more tags to a stream.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a signaling channel.
-
#untag_stream(params = {}) ⇒ Struct
Removes one or more tags from a stream.
-
#update_data_retention(params = {}) ⇒ Struct
Increases or decreases the stream’s data retention period by the value that you specify.
-
#update_image_generation_configuration(params = {}) ⇒ Struct
Updates the ‘StreamInfo` and `ImageProcessingConfiguration` fields.
-
#update_media_storage_configuration(params = {}) ⇒ Struct
Associates a ‘SignalingChannel` to a stream to store the media.
-
#update_notification_configuration(params = {}) ⇒ Struct
Updates the notification information for a stream.
-
#update_signaling_channel(params = {}) ⇒ Struct
Updates the existing signaling channel.
-
#update_stream(params = {}) ⇒ Struct
Updates stream metadata, such as the device name and media type.
-
#update_stream_storage_configuration(params = {}) ⇒ Struct
Updates the storage configuration for an existing Kinesis video stream.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
473 474 475 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 473 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2164 2165 2166 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2164 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2167 2168 2169 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2167 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 2147 2148 2149 2150 2151 2152 2153 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2137 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::KinesisVideo') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-kinesisvideo' context[:gem_version] = '1.94.0' Seahorse::Client::Request.new(handlers, context) end |
#create_signaling_channel(params = {}) ⇒ Types::CreateSignalingChannelOutput
Creates a signaling channel.
‘CreateSignalingChannel` is an asynchronous operation.
529 530 531 532 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 529 def create_signaling_channel(params = {}, = {}) req = build_request(:create_signaling_channel, params) req.send_request() end |
#create_stream(params = {}) ⇒ Types::CreateStreamOutput
Creates a new Kinesis video stream.
When you create a new stream, Kinesis Video Streams assigns it a version number. When you change the stream’s metadata, Kinesis Video Streams updates the version.
‘CreateStream` is an asynchronous operation.
For information about how the service works, see [How it Works].
You must have permissions for the ‘KinesisVideo:CreateStream` action.
[1]: docs.aws.amazon.com/kinesisvideostreams/latest/dg/how-it-works.html
649 650 651 652 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 649 def create_stream(params = {}, = {}) req = build_request(:create_stream, params) req.send_request() end |
#delete_edge_configuration(params = {}) ⇒ Struct
An asynchronous API that deletes a stream’s existing edge configuration, as well as the corresponding media from the Edge Agent.
When you invoke this API, the sync status is set to ‘DELETING`. A deletion process starts, in which active edge jobs are stopped and all media is deleted from the edge device. The time to delete varies, depending on the total amount of stored media. If the deletion process fails, the sync status changes to `DELETE_FAILED`. You will need to re-try the deletion.
When the deletion process has completed successfully, the edge configuration is no longer accessible.
688 689 690 691 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 688 def delete_edge_configuration(params = {}, = {}) req = build_request(:delete_edge_configuration, params) req.send_request() end |
#delete_signaling_channel(params = {}) ⇒ Struct
Deletes a specified signaling channel. ‘DeleteSignalingChannel` is an asynchronous operation. If you don’t specify the channel’s current version, the most recent version is deleted.
719 720 721 722 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 719 def delete_signaling_channel(params = {}, = {}) req = build_request(:delete_signaling_channel, params) req.send_request() end |
#delete_stream(params = {}) ⇒ Struct
Deletes a Kinesis video stream and the data contained in the stream.
This method marks the stream for deletion, and makes the data in the stream inaccessible immediately.
To ensure that you have the latest version of the stream before deleting it, you can specify the stream version. Kinesis Video Streams assigns a version to each stream. When you update a stream, Kinesis Video Streams assigns a new version number. To get the latest stream version, use the ‘DescribeStream` API.
This operation requires permission for the ‘KinesisVideo:DeleteStream` action.
766 767 768 769 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 766 def delete_stream(params = {}, = {}) req = build_request(:delete_stream, params) req.send_request() end |
#describe_edge_configuration(params = {}) ⇒ Types::DescribeEdgeConfigurationOutput
Describes a stream’s edge configuration that was set using the ‘StartEdgeConfigurationUpdate` API and the latest status of the edge agent’s recorder and uploader jobs. Use this API to get the status of the configuration to determine if the configuration is in sync with the Edge Agent. Use this API to evaluate the health of the Edge Agent.
835 836 837 838 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 835 def describe_edge_configuration(params = {}, = {}) req = build_request(:describe_edge_configuration, params) req.send_request() end |
#describe_image_generation_configuration(params = {}) ⇒ Types::DescribeImageGenerationConfigurationOutput
Gets the ‘ImageGenerationConfiguration` for a given Kinesis video stream.
881 882 883 884 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 881 def describe_image_generation_configuration(params = {}, = {}) req = build_request(:describe_image_generation_configuration, params) req.send_request() end |
#describe_mapped_resource_configuration(params = {}) ⇒ Types::DescribeMappedResourceConfigurationOutput
Returns the most current information about the stream. The ‘streamName` or `streamARN` should be provided in the input.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
929 930 931 932 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 929 def describe_mapped_resource_configuration(params = {}, = {}) req = build_request(:describe_mapped_resource_configuration, params) req.send_request() end |
#describe_media_storage_configuration(params = {}) ⇒ Types::DescribeMediaStorageConfigurationOutput
Returns the most current information about the channel. Specify the ‘ChannelName` or `ChannelARN` in the input.
963 964 965 966 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 963 def describe_media_storage_configuration(params = {}, = {}) req = build_request(:describe_media_storage_configuration, params) req.send_request() end |
#describe_notification_configuration(params = {}) ⇒ Types::DescribeNotificationConfigurationOutput
Gets the ‘NotificationConfiguration` for a given Kinesis video stream.
1000 1001 1002 1003 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1000 def describe_notification_configuration(params = {}, = {}) req = build_request(:describe_notification_configuration, params) req.send_request() end |
#describe_signaling_channel(params = {}) ⇒ Types::DescribeSignalingChannelOutput
Returns the most current information about the signaling channel. You must specify either the name or the Amazon Resource Name (ARN) of the channel that you want to describe.
1040 1041 1042 1043 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1040 def describe_signaling_channel(params = {}, = {}) req = build_request(:describe_signaling_channel, params) req.send_request() end |
#describe_stream(params = {}) ⇒ Types::DescribeStreamOutput
Returns the most current information about the specified stream. You must specify either the ‘StreamName` or the `StreamARN`.
1081 1082 1083 1084 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1081 def describe_stream(params = {}, = {}) req = build_request(:describe_stream, params) req.send_request() end |
#describe_stream_storage_configuration(params = {}) ⇒ Types::DescribeStreamStorageConfigurationOutput
Retrieves the current storage configuration for the specified Kinesis video stream.
In the request, you must specify either the ‘StreamName` or the `StreamARN`.
You must have permissions for the ‘KinesisVideo:DescribeStreamStorageConfiguration` action.
1126 1127 1128 1129 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1126 def describe_stream_storage_configuration(params = {}, = {}) req = build_request(:describe_stream_storage_configuration, params) req.send_request() end |
#get_data_endpoint(params = {}) ⇒ Types::GetDataEndpointOutput
Gets an endpoint for a specified stream for either reading or writing. Use this endpoint in your application to read from the specified stream (using the ‘GetMedia` or `GetMediaForFragmentList` operations) or write to it (using the `PutMedia` operation).
<note markdown=“1”> The returned endpoint does not have the API name appended. The client needs to add the API name to the returned endpoint.
</note>
In the request, specify the stream either by ‘StreamName` or `StreamARN`.
1176 1177 1178 1179 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1176 def get_data_endpoint(params = {}, = {}) req = build_request(:get_data_endpoint, params) req.send_request() end |
#get_signaling_channel_endpoint(params = {}) ⇒ Types::GetSignalingChannelEndpointOutput
Provides an endpoint for the specified signaling channel to send and receive messages. This API uses the ‘SingleMasterChannelEndpointConfiguration` input parameter, which consists of the `Protocols` and `Role` properties.
‘Protocols` is used to determine the communication mechanism. For example, if you specify `WSS` as the protocol, this API produces a secure websocket endpoint. If you specify `HTTPS` as the protocol, this API generates an HTTPS endpoint. If you specify `WEBRTC` as the protocol, but the signaling channel isn’t configured for ingestion, you will receive the error ‘InvalidArgumentException`.
‘Role` determines the messaging permissions. A `MASTER` role results in this API generating an endpoint that a client can use to communicate with any of the viewers on the channel. A `VIEWER` role results in this API generating an endpoint that a client can use to communicate only with a `MASTER`.
1231 1232 1233 1234 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1231 def get_signaling_channel_endpoint(params = {}, = {}) req = build_request(:get_signaling_channel_endpoint, params) req.send_request() end |
#list_edge_agent_configurations(params = {}) ⇒ Types::ListEdgeAgentConfigurationsOutput
Returns an array of edge configurations associated with the specified Edge Agent.
In the request, you must specify the Edge Agent ‘HubDeviceArn`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1295 1296 1297 1298 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1295 def list_edge_agent_configurations(params = {}, = {}) req = build_request(:list_edge_agent_configurations, params) req.send_request() end |
#list_signaling_channels(params = {}) ⇒ Types::ListSignalingChannelsOutput
Returns an array of ‘ChannelInfo` objects. Each object describes a signaling channel. To retrieve only those channels that satisfy a specific condition, you can specify a `ChannelNameCondition`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1351 1352 1353 1354 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1351 def list_signaling_channels(params = {}, = {}) req = build_request(:list_signaling_channels, params) req.send_request() end |
#list_streams(params = {}) ⇒ Types::ListStreamsOutput
Returns an array of ‘StreamInfo` objects. Each object describes a stream. To retrieve only streams that satisfy a specific condition, you can specify a `StreamNameCondition`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1411 1412 1413 1414 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1411 def list_streams(params = {}, = {}) req = build_request(:list_streams, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceOutput
Returns a list of tags associated with the specified signaling channel.
1450 1451 1452 1453 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1450 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_tags_for_stream(params = {}) ⇒ Types::ListTagsForStreamOutput
Returns a list of tags associated with the specified stream.
In the request, you must specify either the ‘StreamName` or the `StreamARN`.
1495 1496 1497 1498 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1495 def (params = {}, = {}) req = build_request(:list_tags_for_stream, params) req.send_request() end |
#start_edge_configuration_update(params = {}) ⇒ Types::StartEdgeConfigurationUpdateOutput
An asynchronous API that updates a stream’s existing edge configuration. The Kinesis Video Stream will sync the stream’s edge configuration with the Edge Agent IoT Greengrass component that runs on an IoT Hub Device, setup at your premise. The time to sync can vary and depends on the connectivity of the Hub Device. The ‘SyncStatus` will be updated as the edge configuration is acknowledged, and synced with the Edge Agent.
If this API is invoked for the first time, a new edge configuration will be created for the stream, and the sync status will be set to ‘SYNCING`. You will have to wait for the sync status to reach a terminal state such as: `IN_SYNC`, or `SYNC_FAILED`, before using this API again. If you invoke this API during the syncing process, a `ResourceInUseException` will be thrown. The connectivity of the stream’s edge configuration and the Edge Agent will be retried for 15 minutes. After 15 minutes, the status will transition into the `SYNC_FAILED` state.
To move an edge configuration from one device to another, use DeleteEdgeConfiguration to delete the current edge configuration. You can then invoke StartEdgeConfigurationUpdate with an updated Hub Device ARN.
1602 1603 1604 1605 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1602 def start_edge_configuration_update(params = {}, = {}) req = build_request(:start_edge_configuration_update, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to a signaling channel. A tag is a key-value pair (the value is optional) that you can define and assign to Amazon Web Services resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. For more information, see [Using Cost Allocation Tags] in the *Billing and Cost Management and Cost Management User Guide*.
[1]: docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html
1644 1645 1646 1647 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1644 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#tag_stream(params = {}) ⇒ Struct
Adds one or more tags to a stream. A tag is a key-value pair (the value is optional) that you can define and assign to Amazon Web Services resources. If you specify a tag that already exists, the tag value is replaced with the value that you specify in the request. For more information, see [Using Cost Allocation Tags] in the *Billing and Cost Management and Cost Management User Guide*.
You must provide either the ‘StreamName` or the `StreamARN`.
This operation requires permission for the ‘KinesisVideo:TagStream` action.
A Kinesis video stream can support up to 50 tags.
[1]: docs.aws.amazon.com/awsaccountbilling/latest/aboutv2/cost-alloc-tags.html
1694 1695 1696 1697 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1694 def tag_stream(params = {}, = {}) req = build_request(:tag_stream, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from a signaling channel. In the request, specify only a tag key or keys; don’t specify the value. If you specify a tag key that does not exist, it’s ignored.
1723 1724 1725 1726 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1723 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#untag_stream(params = {}) ⇒ Struct
Removes one or more tags from a stream. In the request, specify only a tag key or keys; don’t specify the value. If you specify a tag key that does not exist, it’s ignored.
In the request, you must provide the ‘StreamName` or `StreamARN`.
1758 1759 1760 1761 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1758 def untag_stream(params = {}, = {}) req = build_request(:untag_stream, params) req.send_request() end |
#update_data_retention(params = {}) ⇒ Struct
Increases or decreases the stream’s data retention period by the value that you specify. To indicate whether you want to increase or decrease the data retention period, specify the ‘Operation` parameter in the request body. In the request, you must specify either the `StreamName` or the `StreamARN`.
This operation requires permission for the ‘KinesisVideo:UpdateDataRetention` action.
Changing the data retention period affects the data in the stream as follows:
-
If the data retention period is increased, existing data is retained for the new retention period. For example, if the data retention period is increased from one hour to seven hours, all existing data is retained for seven hours.
-
If the data retention period is decreased, existing data is retained for the new retention period. For example, if the data retention period is decreased from seven hours to one hour, all existing data is retained for one hour, and any data older than one hour is deleted immediately.
1826 1827 1828 1829 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1826 def update_data_retention(params = {}, = {}) req = build_request(:update_data_retention, params) req.send_request() end |
#update_image_generation_configuration(params = {}) ⇒ Struct
Updates the ‘StreamInfo` and `ImageProcessingConfiguration` fields.
1876 1877 1878 1879 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1876 def update_image_generation_configuration(params = {}, = {}) req = build_request(:update_image_generation_configuration, params) req.send_request() end |
#update_media_storage_configuration(params = {}) ⇒ Struct
Associates a ‘SignalingChannel` to a stream to store the media. There are two signaling modes that you can specify :
-
If ‘StorageStatus` is enabled, the data will be stored in the `StreamARN` provided. In order for WebRTC Ingestion to work, the stream must have data retention enabled.
-
If ‘StorageStatus` is disabled, no data will be stored, and the `StreamARN` parameter will not be needed.
If ‘StorageStatus` is enabled, direct peer-to-peer (master-viewer) connections no longer occur. Peers connect directly to the storage session. You must call the `JoinStorageSession` API to trigger an SDP offer send and establish a connection between a peer and the storage session.
1920 1921 1922 1923 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1920 def update_media_storage_configuration(params = {}, = {}) req = build_request(:update_media_storage_configuration, params) req.send_request() end |
#update_notification_configuration(params = {}) ⇒ Struct
Updates the notification information for a stream.
1961 1962 1963 1964 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 1961 def update_notification_configuration(params = {}, = {}) req = build_request(:update_notification_configuration, params) req.send_request() end |
#update_signaling_channel(params = {}) ⇒ Struct
Updates the existing signaling channel. This is an asynchronous operation and takes time to complete.
If the ‘MessageTtlSeconds` value is updated (either increased or reduced), it only applies to new messages sent via this channel after it’s been updated. Existing messages are still expired as per the previous ‘MessageTtlSeconds` value.
2003 2004 2005 2006 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2003 def update_signaling_channel(params = {}, = {}) req = build_request(:update_signaling_channel, params) req.send_request() end |
#update_stream(params = {}) ⇒ Struct
Updates stream metadata, such as the device name and media type.
You must provide the stream name or the Amazon Resource Name (ARN) of the stream.
To make sure that you have the latest version of the stream before updating it, you can specify the stream version. Kinesis Video Streams assigns a version to each stream. When you update a stream, Kinesis Video Streams assigns a new version number. To get the latest stream version, use the ‘DescribeStream` API.
‘UpdateStream` is an asynchronous operation, and takes time to complete.
2073 2074 2075 2076 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2073 def update_stream(params = {}, = {}) req = build_request(:update_stream, params) req.send_request() end |
#update_stream_storage_configuration(params = {}) ⇒ Struct
Updates the storage configuration for an existing Kinesis video stream.
This operation allows you to modify the storage tier settings for a stream, enabling you to optimize storage costs and performance based on your access patterns.
‘UpdateStreamStorageConfiguration` is an asynchronous operation.
You must have permissions for the ‘KinesisVideo:UpdateStreamStorageConfiguration` action.
2128 2129 2130 2131 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2128 def update_stream_storage_configuration(params = {}, = {}) req = build_request(:update_stream_storage_configuration, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2157 2158 2159 |
# File 'lib/aws-sdk-kinesisvideo/client.rb', line 2157 def waiter_names [] end |