Class: Aws::KinesisVideo::Types::UpdateStreamStorageConfigurationInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::KinesisVideo::Types::UpdateStreamStorageConfigurationInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-kinesisvideo/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_version ⇒ String
The version of the stream whose storage configuration you want to change.
-
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the stream for which you want to update the storage configuration.
-
#stream_name ⇒ String
The name of the stream for which you want to update the storage configuration.
-
#stream_storage_configuration ⇒ Types::StreamStorageConfiguration
The new storage configuration for the stream.
Instance Attribute Details
#current_version ⇒ String
The version of the stream whose storage configuration you want to change. To get the version, call either the ‘DescribeStream` or the `ListStreams` API.
2257 2258 2259 2260 2261 2262 2263 2264 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 2257 class UpdateStreamStorageConfigurationInput < Struct.new( :stream_name, :stream_arn, :current_version, :stream_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#stream_arn ⇒ String
The Amazon Resource Name (ARN) of the stream for which you want to update the storage configuration.
2257 2258 2259 2260 2261 2262 2263 2264 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 2257 class UpdateStreamStorageConfigurationInput < Struct.new( :stream_name, :stream_arn, :current_version, :stream_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#stream_name ⇒ String
The name of the stream for which you want to update the storage configuration.
2257 2258 2259 2260 2261 2262 2263 2264 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 2257 class UpdateStreamStorageConfigurationInput < Struct.new( :stream_name, :stream_arn, :current_version, :stream_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#stream_storage_configuration ⇒ Types::StreamStorageConfiguration
The new storage configuration for the stream. This includes the default storage tier that determines how stream data is stored and accessed.
Different storage tiers offer varying levels of performance and cost optimization to match your specific use case requirements.
2257 2258 2259 2260 2261 2262 2263 2264 |
# File 'lib/aws-sdk-kinesisvideo/types.rb', line 2257 class UpdateStreamStorageConfigurationInput < Struct.new( :stream_name, :stream_arn, :current_version, :stream_storage_configuration) SENSITIVE = [] include Aws::Structure end |